@@ -40,7 +40,7 @@ DUNGEON_MYTHIC_LEVELS = [
     252,  # weekly
 ]
 DUNGEON = [DUNGEON_NORMAL] + [DUNGEON_HEROIC] + [DUNGEON_MYTHIC] + DUNGEON_MYTHIC_LEVELS
-TAZAVESH = 226
+TAZAVESH = [226, 233]
 WORLD_BOSS_CHAINS_OF_DEVASTATION = 233
 
 # raids
